use bot::start_bot;
use config::parse_local_config;
use tracing::{error, info};

pub mod bot;
pub mod config;
pub mod dotenv;

#[tokio::main]
async fn main() {
    println!(include_str!("banner.art"));
    let config = parse_local_config();
    tool_tracing::init::init_tracing(config.tracing.clone(), config.bot_name.clone());

    info!("Init Database");
    let datalake_config = database::create_pool_manager(config.persistence.clone()).unwrap();
    let manager = match database::create_manager_and_init(datalake_config).await {
        Ok(manager) => {
            info!("Database manager created successfully");
            manager
        }
        Err(e) => {
            error!("Failed to create database manager: {}", e);
            return;
        }
    };
    info!("Database manager initialized successfully");

    start_bot(config, manager).await;
}
